{ emacs
, src ? null
, version ? "3a50773"
, hash ? "sha256-7aTinkM+EodoPtuqNXwssQf9fd0EYvyZ/vDA4KE0aew="
}:

{ fetchFromGitHub
, lib
, stdenv
, substituteAll
, libgccjit
, pkg-config
, makeWrapper
, texinfo
, autoreconfHook
, gettext
, gnutls
, harfbuzz
, jansson
, libxml2
, ncurses
, libotf
, gtk3-x11
, sqlite
, tree-sitter
, cairo
, librsvg
}:

let orElse = (import ../utils.nix).orElse;
    src' = orElse src (fetchFromGitHub {
      owner = "emacs-mirror";
      repo = "emacs";
      rev = version;
      sha256 = hash;
    });
    libGccJitLibraryPaths = [
      "${lib.getLib libgccjit}/lib/gcc"
      "${lib.getLib stdenv.cc.libc}/lib"
    ] ++ lib.optionals (stdenv.cc?cc.libgcc) [
      "${lib.getLib stdenv.cc.cc.libgcc}/lib"
    ];
in emacs.overrideAttrs (final: prev: {
  inherit version;
  src = src';

  patches = [
    (substituteAll {
      src = ./patch-native-comp.patch;
      backendPath = (lib.concatStringsSep " "
        (builtins.map (x: ''"-B${x}"'') ([
          # Paths necessary so the JIT compiler finds its libraries:
          "${lib.getLib libgccjit}/lib"
        ] ++ libGccJitLibraryPaths ++ [
          # Executable paths necessary for compilation (ld, as):
          "${lib.getBin stdenv.cc.cc}/bin"
          "${lib.getBin stdenv.cc.bintools}/bin"
          "${lib.getBin stdenv.cc.bintools.bintools}/bin"
        ])));
    })
  ];

  CFLAGS = "-march=native -mtune=native -O2 -pipe";
  CXXFLAGS = "-march=native -mtune=native -O2 -pipe";

  configureFlags = [
    "--without-all" # Just our options
    "--enable-link-time-optimization"
    "--with-x-toolkit=gtk3"
    "--with-json"
    "--with-rsvg"
    "--with-cairo"
    "--with-harfbuzz"
    "--with-libotf"
    "--with-threads"
    "--with-modules"
    "--with-native-compilation"
    "--with-file-notification=yes"
    "--without-compress-install"
    "--with-x"
    "--with-xml2"
    "--with-zlib"
    "--with-xinput2"
    "--with-gnutls"
    "--with-tree-sitter"
  ];

  nativeBuildInputs = [
    pkg-config
    makeWrapper
    texinfo
    autoreconfHook
  ];
  buildInputs = [
    gettext gnutls harfbuzz.dev jansson libxml2 ncurses libotf gtk3-x11
    (lib.lowPrio libgccjit) sqlite tree-sitter cairo librsvg
  ];
})
