{ pkgs, unstablePkgs, idyllsPkgs, atuinPkgs, mozillaPkgs, ... }:

{
  programs.fish.enable = true;
  programs.steam = {
    enable = true;
    remotePlay.openFirewall = true;
  };
  programs.gnupg.agent = {
    enable = true;
    pinentryFlavor = "gtk2";
  };

  programs.ssh = {
    startAgent = true;
    enableAskPassword = true;
    askPassword = "${pkgs.pinentry-qt}/bin/pinentry";
  };

  users.users.idylls = {
    isNormalUser = true;
    extraGroups = [ "wheel" ]; # Enable ‘sudo’ for the user.
    packages = [
      # Dev Tools
      pkgs.git idyllsPkgs.emacs pkgs.kitty pkgs.fd idyllsPkgs.eww pkgs.deno
      pkgs.ripgrep atuinPkgs.atuin pkgs.stow pkgs.cmake pkgs.gnumake pkgs.ninja
      pkgs.entr

      # Desktop
      pkgs.rofi pkgs.i3 pkgs.sxhkd pkgs.keepassxc pkgs.dunst pkgs.slock
      pkgs.nitrogen pkgs.lxappearance pkgs.gnome.adwaita-icon-theme
      pkgs.gnome.gnome-themes-extra pkgs.pavucontrol pkgs.gpick pkgs.unzip
      pkgs.imagemagick

      # Games
      idyllsPkgs.runelite

      # Applications
      (mozillaPkgs.lib.firefoxOverlay.firefoxVersion {
        version = "116.0a1";
        name = "Nightly";
        release = false;
        wmClass = "firefox-nightly";
        info = {
          chksum = "https://archive.mozilla.org/pub/firefox/nightly/2023/07/2023-07-02-09-24-54-mozilla-central/firefox-116.0a1.en-US.linux-x86_64.checksums";
          chksumSig = null;
          url = "https://ftp.mozilla.org/pub/firefox/nightly/2023/07/2023-07-02-09-24-54-mozilla-central/firefox-116.0a1.en-US.linux-x86_64.tar.bz2";
          sha512 = "e72ce0fa09c829d3c62bc69512eb71a62ab94ad9911f375a65b1cea66549c6abbfa9c315e19ae498f931fd4c56dddfbc1fe350f4582c685030f06caa4e4b54d1";
          sig = "https://ftp.mozilla.org/pub/firefox/nightly/2023/07/2023-07-02-09-24-54-mozilla-central/firefox-116.0a1.en-US.linux-x86_64.tar.bz2.asc";
          sigSha512 = "1e1cc3572f4c55a7d838783438573ff268996639e1f31d292a4ad7e614ab8d4e8afdaefad7dfd6a1c0b93d96943f50044272ca53141d0792cb58d81407addd3b";
        };
      })
      pkgs.discord unstablePkgs.signal-desktop
      (pkgs.wrapOBS {
        plugins = with pkgs.obs-studio-plugins; [
          input-overlay advanced-scene-switcher obs-pipewire-audio-capture
          obs-vkcapture
        ];
      })
      pkgs.chromium pkgs.lxtask
    ];
    shell = pkgs.fish;
  };
}
